function [ p ] = BuildPortfolio(price_data, use_data)
%%Constructs an array containing optimal weights for an allocation of capital
%%over the provided stocks. Optimality is determined by the algotithm
%%specified in the Config.m file

%Parameters
%price_data - matrix containing price data for stocks on many dates
%use_data - binary array specifying which stocks are usable on a given date

%Return Values
%p - array of portfolio weights

    params = Config();
    
    %construct the portfolio using the specified algorithm
    switch params.alg
        case 'simple_uniform'
            p = SimpUni(use_data);
        case 'markowitz'
            p = Markowitz(price_data, use_data);
        case 'mdd'
            p = MDD(price_data, use_data);
        case 'min_mdd'
            p = MinMDD(price_data, use_data);
        case 'vol_weighted'
            p = VolWeighted(price_data, use_data);
        otherwise
            error('Unknown Selection Algorithm');
    end
    
end