function [ port ] = MDD(price_data, use_data)
    params = Config();
    
    lambda = params.lambda;
    PHOR = params.PHOR;
    
    [stock_values, ~, universe] = WindowData(price_data, use_data);

    dimen = size(stock_values);
    R = zeros(dimen);
    %fill R with the day by day cumulative return for each stock
    for row=2:dimen(1)
       for col=1:dimen(2)
            cur_val = stock_values(row, col);
            org_val = stock_values(1,col);
            if (org_val ~= 0)
                R(row, col) = (cur_val-org_val)/org_val;
            end
       end
    end

    num_use = length(universe);
    %uniform weights
    uni = ones(num_use,1)/num_use;
    draw = R*uni;

    %Code to Calculate Maximum Drawdown over this period when using
    %a uniform portfolio allocation
    DD = zeros(length(draw));
    MDD = 0;  
    peak = -99999;
    for i = 1:length(draw)
      if (draw(i) > peak && draw(i) ~= 0) 
        peak = draw(i);
      end
      DD(i) = peak-draw(i);
      if (DD(i) > MDD)
        MDD = DD(i);
      end
    end

    Ot = zeros(PHOR+1,1);
    It = eye(PHOR+1);
    On = zeros(num_use, 1);

    f = -1*[0; Ot; R(end, 1:end)'];
    A = [Ot It -1*R; Ot -1*It R; [It Ot]+[Ot -1*It] Ot*On'];
    b = [lambda*MDD*ones(PHOR+1,1); Ot; Ot];
    Aeq = [1 Ot' On'; 0 Ot' ones(1,num_use)];
    %Aeq = [1 Ot' On'];
    %beq = 0;
    beq = [0; 1];
    LB = [0; Ot; On];
    UB = [Inf; Inf*ones(PHOR+1,1); ones(num_use, 1)];

    opts = optimset('Display','none');

    [X, ~, EXITFLAG] = linprog(f,A,b,Aeq,beq,LB,UB,[],opts);
    if (EXITFLAG ~= 1)
       disp(EXITFLAG);
       error('Error solving linear program');
    end

    p_wts = X(PHOR+3:end)';
    %p_wts = p_wts/sum(p_wts);

    port = zeros(1, length(use_data));

    for i=1:length(universe) 
       port(universe(i)) = p_wts(i);
    end

end