function [ port ] = Markowitz(price_data, use_data)
    params = Config();  
    lambda = params.lambda;

    [~, returns, universe] = WindowData(price_data, use_data);

    avg_r = mean(returns);
    min_r = min(avg_r);
    max_r = max(avg_r);

    cvr = cov(returns);

    L = length(cvr);
    opts = optimset('Algorithm','active-set','Display','off');
    target = lambda*max_r + (1-lambda)*min_r;
    theta = quadprog(cvr, zeros(L,1), [], [], avg_r, target, zeros(L,1), ones(L,1), [], opts);
    p_wts = theta;

    %normalize the weights so that they sum to 1
    p_wts = p_wts/sum(p_wts);

    port = zeros(1, length(use_data));

    for i=1:length(universe)
       port(universe(i)) = p_wts(i);
    end
end